Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(786)

Unified Diff: chrome/browser/ui/views/session_crashed_bubble_view.h

Issue 2644663003: Offer to open the startup pages after a crash. (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/session_crashed_bubble_view.h
diff --git a/chrome/browser/ui/views/session_crashed_bubble_view.h b/chrome/browser/ui/views/session_crashed_bubble_view.h
index c8838dee15628c53a8d38d016c5eb6a1a3ac017c..7ab79146ef86e27d334f093763844d17a3dc4a79 100644
--- a/chrome/browser/ui/views/session_crashed_bubble_view.h
+++ b/chrome/browser/ui/views/session_crashed_bubble_view.h
@@ -49,6 +49,7 @@ class SessionCrashedBubbleView : public SessionCrashedBubble,
void OnWidgetDestroying(views::Widget* widget) override;
views::View* CreateFootnoteView() override;
bool Accept() override;
+ bool Cancel() override;
bool Close() override;
int GetDialogButtons() const override;
base::string16 GetDialogButtonLabel(ui::DialogButton button) const override;
@@ -64,6 +65,15 @@ class SessionCrashedBubbleView : public SessionCrashedBubble,
// Restore previous session after user selects so.
void RestorePreviousSession();
+ // Open startup pages after user selects so.
+ void OpenStartupPages();
+
+ // Enable UMA if the user accepted the offer.
+ void MaybeEnableUMA();
+
+ // Close and destroy the bubble.
+ void CloseBubble();
+
// Used for opening the question mark link as well as access the tab strip.
Browser* browser_;
@@ -73,9 +83,9 @@ class SessionCrashedBubbleView : public SessionCrashedBubble,
// Whether or not the UMA opt-in option should be shown.
bool offer_uma_optin_;
- // Whether or not the user chose to restore previous session. It is used to
- // collect bubble usage stats.
- bool restored_;
+ // Whether or not the user ignored the bubble. It is used to collect bubble
+ // usage stats.
+ bool ignored_;
DISALLOW_COPY_AND_ASSIGN(SessionCrashedBubbleView);
};
« no previous file with comments | « chrome/browser/ui/startup/startup_browser_creator.cc ('k') | chrome/browser/ui/views/session_crashed_bubble_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698